@@ -159,13 +159,10 @@ sub on_valid_form
     $m_hrSettings->{cgi}{cookiePath} = param('cookiePath');
     $m_hrSettings->{cgi}{mod_rewrite} = param('mod_rewrite');
     $m_hrSettings->{cgi}{serverName} = param('serverName');
-    $m_hrSettings->{sidebar}{left} = (param('sidebarLeft') eq 'Enabled') ? 1 : 0;
-    $m_hrSettings->{sidebar}{right} = ( param('sidebarRight') eq 'Enabled') ? 1 : 0;
     $m_hrSettings->{htmlright} = param('htmlright');
     $m_hrSettings->{floodtime} = param('floodtime');
     $m_hrSettings->{news}{messages}  = param('messages');
     $m_hrSettings->{news}{maxlength} = param('maxlength');
-    $m_hrSettings->{ajax} = param('ajaxenabled') eq 'Enabled' ? 1 : 0;
     #general
     $m_hrSettings->{language}        = param('language');
     $m_hrSettings->{defaultAction}   = param('defaultAction');
