@@ -1,57 +1,57 @@
 $VAR1 = {
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'version' => '0.91',
           'floodtime' => 10,
-          'scriptAlias' => 'cgi-bin',
-          'cgi' => {
-                     'title' => 'MySQL::Admin',
-                     'expires' => '+1y',
-                     'bin' => '/var/www/cgi-bin',
-                     'style' => 'mysql',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'cookiePath' => '/',
-                     'alias' => 'cgi-bin',
-                     'serverName' => 'localhost'
-                   },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'news' => {
-                      'maxlength' => '2000',
-                      'right' => 5,
-                      'messages' => '5',
-                      'captcha' => 3
-                    },
-          'language' => 'en',
-          'mod' => 'n',
           'admin' => {
                        'password' => 'testpass'
                      },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'language' => 'en',
           'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'scriptAlias' => 'cgi-bin',
           'tree' => {
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
-                      'links' => '/var/www/cgi-bin/config/links.pl'
+                      'links' => '/var/www/cgi-bin/config/links.pl',
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
                     },
-          'files' => {
-                       'group' => 'lze',
-                       'owner' => 'lze',
-                       'chmod' => '0755'
-                     },
+          'mod' => 'n',
           'database' => {
-                          'host' => 'localhost',
-                          'user' => 'root',
-                          'password' => '',
-                          'CurrentPass' => '',
-                          'CurrentDb' => 'LZE',
-                          'name' => 'LZE',
                           'CurrentHost' => 'localhost',
-                          'CurrentUser' => 'root'
+                          'host' => 'localhost',
+                          'name' => 'LZE',
+                          'CurrentPass' => '',
+                          'password' => '',
+                          'CurrentUser' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'user' => 'root'
                         },
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'cgi' => {
+                     'style' => 'mysql',
+                     'title' => 'MySQL::Admin',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'serverName' => 'localhost',
+                     'alias' => 'cgi-bin',
+                     'expires' => '+1y',
+                     'bin' => '/var/www/cgi-bin',
+                     'cookiePath' => '/'
+                   },
+          'version' => '0.92',
           'uploads' => {
+                         'path' => '/var/www/htdocs//download',
                          'chmod' => 438,
-                         'maxlength' => 21000000,
-                         'path' => '/var/www/htdocs//download'
+                         'maxlength' => 21000000
                        },
-          'defaultAction' => 'ShowDatabases'
+          'files' => {
+                       'chmod' => '0755',
+                       'group' => 'lze',
+                       'owner' => 'lze'
+                     },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'news' => {
+                      'captcha' => 3,
+                      'maxlength' => '2000',
+                      'right' => 5,
+                      'messages' => '5'
+                    },
+          'defaultAction' => 'ShowDatabases',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'translate' => '/var/www/cgi-bin/config/translate.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
