@@ -6,8 +6,8 @@ use MySQL::Admin::Translate;
 use vars qw($m_hrLang );
 use CGI qw(param header);
 *m_hrLang = \$MySQL::Admin::Translate::lang;
-loadTranslate('config/translate.pl');
-my $content ="Lang =function (){\n";
+loadTranslate('%CONFIG%/translate.pl');
+my $content = "Lang =function (){\n";
 foreach my $lng (keys %{$m_hrLang}){
     foreach my $key (keys %{$m_hrLang->{$lng}}){
       my $out = lc  $key;
