@@ -41,7 +41,7 @@ $VAR1 = {
                    'expires'      => '+1y'
          },
          'database' => {
-                        'password' => '',
+                        'password' => 'keinz',
                         'user'     => 'root',
                         'name'     => 'LZE',
                         'host'     => 'localhost'
